@@ -4,17 +4,17 @@ A module for asymmetric's callback schemas.
 
 
 CALLBACK_OBJECT_SCHEMA = {
-    "type": "object",
-    "properties": {
-        "callback_url_header": {
-            "type": "string",
-        },
-        "callback_method_header": {
-            "type": "string",
-        },
-        "custom_callback_key_header": {
-            "type": "string",
-        },
+    "callback_url_header": {
+        "required": False,
+        "type": str,
+    },
+    "callback_method_header": {
+        "required": False,
+        "type": str,
+    },
+    "custom_callback_key_header": {
+        "required": False,
+        "type": str,
     },
 }
 
