@@ -3,8 +3,12 @@ The main module of asymmetric.
 """
 
 import asyncio
+from typing import Any, Callable, Dict, List, Union
+
 from starlette.applications import Starlette
+from starlette.requests import Request
 from starlette.responses import JSONResponse
+from starlette.types import Receive, Scope, Send
 
 from asymmetric.callbacks.core import CallbackClient
 from asymmetric.constants import HTTP_METHODS
@@ -13,10 +17,10 @@ from asymmetric.errors import DuplicatedEndpointError
 from asymmetric.helpers import http_verb
 from asymmetric.loggers import log, log_request
 from asymmetric.utils import (
-    generic_call,
-    handle_error,
     filter_params,
+    generic_call,
     get_body,
+    handle_error,
     terminate_program,
 )
 
@@ -28,14 +32,14 @@ class Asymmetric:
     the asymmetric package.
     """
 
-    def __init__(self):
-        self.__app = Starlette()
-        self.__endpoints = Endpoints()
+    def __init__(self) -> None:
+        self.__app: Starlette = Starlette()
+        self.__endpoints: Endpoints = Endpoints()
 
-    async def __call__(self, scope, receive, send):
-        return await self.__app.__call__(scope, receive, send)
+    async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
+        await self.__app.__call__(scope, receive, send)
 
-    def __getattr__(self, attr):
+    def __getattr__(self, attr: Any) -> Any:
         """
         Intercept all attribute/method calls to the assymetric object
         if they aren't part of it and redirect them to the Starlette app.
@@ -43,21 +47,19 @@ class Asymmetric:
         return getattr(self.__app, attr)
 
     def router(
-            self,
-            route,
-            methods=["post"],
-            response_code=200,
-            callback=False
-    ):
+        self,
+        route: str,
+        methods: List[str] = ["post"],
+        response_code: int = 200,
+        callback: Union[Dict[str, Any], bool] = False,
+    ) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
         """
         Method to use for decorating the function wanting to be transformed
         to an API.
         """
-        methods = [
-            http_verb(x) for x in methods if http_verb(x) in HTTP_METHODS
-        ]
+        methods = [http_verb(x) for x in methods if http_verb(x) in HTTP_METHODS]
 
-        def decorator(function):
+        def decorator(function: Callable[..., Any]) -> Callable[..., Any]:
             """
             Function decorator. Receives the main function and wraps it as a
             starlette endpoint. Returns the original unwrapped function.
@@ -68,9 +70,8 @@ class Asymmetric:
                 callback_client.prepare_and_validate_finders()
 
             @self.__app.route(route, methods=methods)
-            async def wrapper(request):
-                asyncio.ensure_future(
-                    log_request(request, route, function))
+            async def wrapper(request: Request) -> JSONResponse:
+                asyncio.ensure_future(log_request(request, route, function))
 
                 try:
                     # Get the body
@@ -84,7 +85,7 @@ class Asymmetric:
                         # Process and return the result
                         return JSONResponse(
                             await generic_call(function, params),
-                            status_code=response_code
+                            status_code=response_code,
                         )
 
                     return callback_client.handle_callback(headers, params)
@@ -98,13 +99,14 @@ class Asymmetric:
                     methods,
                     response_code,
                     function,  # Save unchanged function
-                    wrapper,   # Save starlette decorated function
+                    wrapper,  # Save starlette decorated function
                 )
             except DuplicatedEndpointError as err:
                 log(f"DuplicatedRouteError: {err}", level="error")
                 terminate_program()  # TODO: exit the server correctly
 
             return function
+
         return decorator
 
 
